#!/bin/sh

###
#
# $Id: reptile-startup.sh,v 1.7 2001/09/20 23:39:42 burton Exp $
#
# Commentary:
#
###

TOMCAT_HOME="."

APPLICATION="reptile"

java -classpath $TOMCAT_HOME/lib/ant.jar:$TOMCAT_HOME/lib/xerces.jar \
     -Dtomcat.home=$TOMCAT_HOME org.apache.tools.ant.Main \
     -Dlog4j.debug=true \
     -emacs -file $TOMCAT_HOME/reptile.xml startup 
